/***************************************************************************
                          job_modifyfavourite.h  -  description
                             -------------------
    begin                : Wed May 9 2001
    copyright            : (C) 2001 by Holger Sattel
    email                : hsattel@rumms.uni-mannheim.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef JOB_MODIFYFAVOURITE_H
#define JOB_MODIFYFAVOURITE_H

#include "prokyon.h"

#include "jobbase.h"

class Job_ModifyFavourite : public JobBase  {
public:
    Job_ModifyFavourite(int _id, bool _state);

    int type() {
        return JOB_MODIFY_FAVOURITE;
    }

    void run();

    ~Job_ModifyFavourite();

private:
    int id;
    bool state;
};

#endif
